@@ -1,5 +1,5 @@
 package Microsoft::AdCenter::CampaignManagementService::ApiFaultDetail;
-# Copyright (C) 2011 Xerxes Tsang
+# Copyright (C) 2010 Xerxes Tsang
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of Perl Artistic License.
 
@@ -49,20 +49,7 @@ sub _attribute_type {
     return $self->SUPER::_attribute_type($attribute);
 }
 
-our %_attribute_min_occurs = (
-    BatchErrors => 0,
-    OperationErrors => 0,
-);
-
-sub _attribute_min_occurs {
-    my ($self, $attribute) = @_;
-    if (exists $_attribute_min_occurs{$attribute}) {
-        return $_attribute_min_occurs{$attribute};
-    }
-    return $self->SUPER::_attribute_min_occurs($attribute);
-}
-
-__PACKAGE__->mk_accessors(@_attributes);
+__PACKAGE__->mk_accessors(__PACKAGE__->_attributes);
 
 1;
 
