@@ -1,5 +1,5 @@
 package Microsoft::AdCenter::ReportingService;
-# Copyright (C) 2011 Xerxes Tsang
+# Copyright (C) 2010 Xerxes Tsang
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of Perl Artistic License.
 
@@ -34,7 +34,7 @@ See L<http://msdn.microsoft.com/en-us/library/ee730328%28v=MSADS.70%29.aspx> for
 
 Changes the end point for this service client.
 
-Default value: https://adcenterapi.microsoft.com/Api/Advertiser/V7/Reporting/ReportingService.svc
+Default value: https://adcenterapi.microsoft.com/Api/Advertiser/V6/Reporting/ReportingService.svc
 
 =head2 ApplicationToken
 
@@ -77,24 +77,24 @@ sub _class_name {
 }
 
 sub _namespace_uri {
-    return 'https://adcenter.microsoft.com/v7';
+    return 'https://adcenter.microsoft.com/v6';
 }
 
 sub _default_location {
-    return 'https://adcenterapi.microsoft.com/Api/Advertiser/V7/Reporting/ReportingService.svc';
+    return 'https://adcenterapi.microsoft.com/Api/Advertiser/V6/Reporting/ReportingService.svc';
 }
 
 sub _wsdl {
-    return 'https://adcenterapi.microsoft.com/Api/Advertiser/v7/Reporting/ReportingService.svc?wsdl';
+    return 'https://adcenterapi.microsoft.com/Api/Advertiser/v6/Reporting/ReportingService.svc?wsdl';
 }
 
 our $_request_headers = [
-    { name => 'ApplicationToken', type => 'string', namespace => 'https://adcenter.microsoft.com/v7' },
-    { name => 'CustomerAccountId', type => 'string', namespace => 'https://adcenter.microsoft.com/v7' },
-    { name => 'CustomerId', type => 'string', namespace => 'https://adcenter.microsoft.com/v7' },
-    { name => 'DeveloperToken', type => 'string', namespace => 'https://adcenter.microsoft.com/v7' },
-    { name => 'Password', type => 'string', namespace => 'https://adcenter.microsoft.com/v7' },
-    { name => 'UserName', type => 'string', namespace => 'https://adcenter.microsoft.com/v7' }
+    { name => 'ApplicationToken', type => 'string', namespace => 'https://adcenter.microsoft.com/v6' },
+    { name => 'CustomerAccountId', type => 'string', namespace => 'https://adcenter.microsoft.com/v6' },
+    { name => 'CustomerId', type => 'string', namespace => 'https://adcenter.microsoft.com/v6' },
+    { name => 'DeveloperToken', type => 'string', namespace => 'https://adcenter.microsoft.com/v6' },
+    { name => 'Password', type => 'string', namespace => 'https://adcenter.microsoft.com/v6' },
+    { name => 'UserName', type => 'string', namespace => 'https://adcenter.microsoft.com/v6' }
 ];
 
 our $_request_headers_expanded = {
@@ -115,7 +115,7 @@ sub _request_headers_expanded {
 }
 
 our $_response_headers = [
-    { name => 'TrackingId', type => 'string', namespace => 'https://adcenter.microsoft.com/v7' }
+    { name => 'TrackingId', type => 'string', namespace => 'https://adcenter.microsoft.com/v6' }
 ];
 
 our $_response_headers_expanded = {
@@ -153,7 +153,7 @@ sub PollGenerateReport {
         request => {
             name => 'PollGenerateReportRequest',
             parameters => [
-                { name => 'ReportRequestId', type => 'string', namespace => 'https://adcenter.microsoft.com/v7' }
+                { name => 'ReportRequestId', type => 'string', namespace => 'https://adcenter.microsoft.com/v6' }
             ]
         },
         response => {
@@ -186,7 +186,7 @@ sub SubmitGenerateReport {
         request => {
             name => 'SubmitGenerateReportRequest',
             parameters => [
-                { name => 'ReportRequest', type => 'ReportRequest', namespace => 'https://adcenter.microsoft.com/v7' }
+                { name => 'ReportRequest', type => 'ReportRequest', namespace => 'https://adcenter.microsoft.com/v6' }
             ]
         },
         response => {
@@ -197,50 +197,47 @@ sub SubmitGenerateReport {
 }
 
 our %_simple_types = (
-    AccountPerformanceReportColumn => 'https://adcenter.microsoft.com/v7',
-    AdDistributionReportFilter => 'https://adcenter.microsoft.com/v7',
-    AdDynamicTextPerformanceReportColumn => 'https://adcenter.microsoft.com/v7',
-    AdGroupPerformanceReportColumn => 'https://adcenter.microsoft.com/v7',
-    AdGroupStatusReportFilter => 'https://adcenter.microsoft.com/v7',
-    AdPerformanceReportColumn => 'https://adcenter.microsoft.com/v7',
-    AdStatusReportFilter => 'https://adcenter.microsoft.com/v7',
-    AdTypeReportFilter => 'https://adcenter.microsoft.com/v7',
-    AgeGenderDemographicReportColumn => 'https://adcenter.microsoft.com/v7',
-    AgeGroupReportFilter => 'https://adcenter.microsoft.com/v7',
-    BehavioralPerformanceReportColumn => 'https://adcenter.microsoft.com/v7',
-    BehavioralTargetReportColumn => 'https://adcenter.microsoft.com/v7',
-    BidMatchTypeReportFilter => 'https://adcenter.microsoft.com/v7',
-    BudgetSummaryReportColumn => 'https://adcenter.microsoft.com/v7',
-    BudgetSummaryReportTimePeriod => 'https://adcenter.microsoft.com/v7',
-    CampaignPerformanceReportColumn => 'https://adcenter.microsoft.com/v7',
-    CampaignStatusReportFilter => 'https://adcenter.microsoft.com/v7',
-    CashbackReportFilter => 'https://adcenter.microsoft.com/v7',
-    ComponentTypeFilter => 'https://adcenter.microsoft.com/v7',
-    ConversionPerformanceReportColumn => 'https://adcenter.microsoft.com/v7',
-    CountryReportFilter => 'https://adcenter.microsoft.com/v7',
-    DeliveredMatchTypeReportFilter => 'https://adcenter.microsoft.com/v7',
-    DestinationUrlPerformanceReportColumn => 'https://adcenter.microsoft.com/v7',
-    DeviceTypeReportFilter => 'https://adcenter.microsoft.com/v7',
-    GenderReportFilter => 'https://adcenter.microsoft.com/v7',
-    GoalsAndFunnelsReportColumn => 'https://adcenter.microsoft.com/v7',
-    KeywordPerformanceReportColumn => 'https://adcenter.microsoft.com/v7',
-    LanguageAndRegionReportFilter => 'https://adcenter.microsoft.com/v7',
-    MetroAreaDemographicReportColumn => 'https://adcenter.microsoft.com/v7',
-    NonHourlyReportAggregation => 'https://adcenter.microsoft.com/v7',
-    PublisherUsagePerformanceReportColumn => 'https://adcenter.microsoft.com/v7',
-    ReportAggregation => 'https://adcenter.microsoft.com/v7',
-    ReportFormat => 'https://adcenter.microsoft.com/v7',
-    ReportLanguage => 'https://adcenter.microsoft.com/v7',
-    ReportRequestStatusType => 'https://adcenter.microsoft.com/v7',
-    ReportTimePeriod => 'https://adcenter.microsoft.com/v7',
-    RichAdComponentPerformanceReportColumn => 'https://adcenter.microsoft.com/v7',
-    RichAdSubTypeFilter => 'https://adcenter.microsoft.com/v7',
-    SearchQueryPerformanceReportColumn => 'https://adcenter.microsoft.com/v7',
-    SearchQueryReportAggregation => 'https://adcenter.microsoft.com/v7',
-    SegmentationReportColumn => 'https://adcenter.microsoft.com/v7',
-    SitePerformanceReportColumn => 'https://adcenter.microsoft.com/v7',
-    TacticChannelReportColumn => 'https://adcenter.microsoft.com/v7',
-    TrafficSourcesReportColumn => 'https://adcenter.microsoft.com/v7',
+    AccountPerformanceReportColumn => 'https://adcenter.microsoft.com/v6',
+    AdDistributionReportFilter => 'https://adcenter.microsoft.com/v6',
+    AdDynamicTextPerformanceReportColumn => 'https://adcenter.microsoft.com/v6',
+    AdGroupPerformanceReportColumn => 'https://adcenter.microsoft.com/v6',
+    AdGroupStatusReportFilter => 'https://adcenter.microsoft.com/v6',
+    AdPerformanceReportColumn => 'https://adcenter.microsoft.com/v6',
+    AdStatusReportFilter => 'https://adcenter.microsoft.com/v6',
+    AdTypeReportFilter => 'https://adcenter.microsoft.com/v6',
+    AgeGenderDemographicReportColumn => 'https://adcenter.microsoft.com/v6',
+    AgeGroupReportFilter => 'https://adcenter.microsoft.com/v6',
+    BehavioralPerformanceReportColumn => 'https://adcenter.microsoft.com/v6',
+    BehavioralTargetReportColumn => 'https://adcenter.microsoft.com/v6',
+    BiddedMatchTypeReportFilter => 'https://adcenter.microsoft.com/v6',
+    BudgetSummaryReportColumn => 'https://adcenter.microsoft.com/v6',
+    BudgetSummaryReportTimePeriod => 'https://adcenter.microsoft.com/v6',
+    CampaignPerformanceReportColumn => 'https://adcenter.microsoft.com/v6',
+    CampaignStatusReportFilter => 'https://adcenter.microsoft.com/v6',
+    CashbackReportFilter => 'https://adcenter.microsoft.com/v6',
+    ConversionPerformanceReportColumn => 'https://adcenter.microsoft.com/v6',
+    CountryReportFilter => 'https://adcenter.microsoft.com/v6',
+    DeliveredMatchTypeReportFilter => 'https://adcenter.microsoft.com/v6',
+    DestinationUrlPerformanceReportColumn => 'https://adcenter.microsoft.com/v6',
+    DeviceTypeReportFilter => 'https://adcenter.microsoft.com/v6',
+    GenderReportFilter => 'https://adcenter.microsoft.com/v6',
+    GoalsAndFunnelsReportColumn => 'https://adcenter.microsoft.com/v6',
+    KeywordPerformanceReportColumn => 'https://adcenter.microsoft.com/v6',
+    LanguageAndRegionReportFilter => 'https://adcenter.microsoft.com/v6',
+    MetroAreaDemographicReportColumn => 'https://adcenter.microsoft.com/v6',
+    NonHourlyReportAggregation => 'https://adcenter.microsoft.com/v6',
+    PublisherUsagePerformanceReportColumn => 'https://adcenter.microsoft.com/v6',
+    ReportAggregation => 'https://adcenter.microsoft.com/v6',
+    ReportFormat => 'https://adcenter.microsoft.com/v6',
+    ReportLanguage => 'https://adcenter.microsoft.com/v6',
+    ReportRequestStatusType => 'https://adcenter.microsoft.com/v6',
+    ReportTimePeriod => 'https://adcenter.microsoft.com/v6',
+    SearchQueryPerformanceReportColumn => 'https://adcenter.microsoft.com/v6',
+    SearchQueryReportAggregation => 'https://adcenter.microsoft.com/v6',
+    SegmentationReportColumn => 'https://adcenter.microsoft.com/v6',
+    SitePerformanceReportColumn => 'https://adcenter.microsoft.com/v6',
+    TacticChannelReportColumn => 'https://adcenter.microsoft.com/v6',
+    TrafficSourcesReportColumn => 'https://adcenter.microsoft.com/v6',
     char => 'http://schemas.microsoft.com/2003/10/Serialization/',
     duration => 'http://schemas.microsoft.com/2003/10/Serialization/',
     guid => 'http://schemas.microsoft.com/2003/10/Serialization/',
@@ -297,8 +294,6 @@ our @_complex_types = (qw/
     ReportRequest
     ReportRequestStatus
     ReportTime
-    RichAdComponentPerformanceReportFilter
-    RichAdComponentPerformanceReportRequest
     SearchQueryPerformanceReportFilter
     SearchQueryPerformanceReportRequest
     SegmentationReportFilter
@@ -318,7 +313,7 @@ sub _complex_types {
 
 our %_array_types = (
     ArrayOfAccountPerformanceReportColumn => {
-        namespace_uri => 'https://adcenter.microsoft.com/v7',
+        namespace_uri => 'https://adcenter.microsoft.com/v6',
         element_name => 'AccountPerformanceReportColumn',
         element_type => 'AccountPerformanceReportColumn'
     },
@@ -328,125 +323,130 @@ our %_array_types = (
         element_type => 'AdApiError'
     },
     ArrayOfAdDynamicTextPerformanceReportColumn => {
-        namespace_uri => 'https://adcenter.microsoft.com/v7',
+        namespace_uri => 'https://adcenter.microsoft.com/v6',
         element_name => 'AdDynamicTextPerformanceReportColumn',
         element_type => 'AdDynamicTextPerformanceReportColumn'
     },
     ArrayOfAdGroupPerformanceReportColumn => {
-        namespace_uri => 'https://adcenter.microsoft.com/v7',
+        namespace_uri => 'https://adcenter.microsoft.com/v6',
         element_name => 'AdGroupPerformanceReportColumn',
         element_type => 'AdGroupPerformanceReportColumn'
     },
     ArrayOfAdGroupReportScope => {
-        namespace_uri => 'https://adcenter.microsoft.com/v7',
+        namespace_uri => 'https://adcenter.microsoft.com/v6',
         element_name => 'AdGroupReportScope',
         element_type => 'AdGroupReportScope'
     },
     ArrayOfAdPerformanceReportColumn => {
-        namespace_uri => 'https://adcenter.microsoft.com/v7',
+        namespace_uri => 'https://adcenter.microsoft.com/v6',
         element_name => 'AdPerformanceReportColumn',
         element_type => 'AdPerformanceReportColumn'
     },
     ArrayOfAgeGenderDemographicReportColumn => {
-        namespace_uri => 'https://adcenter.microsoft.com/v7',
+        namespace_uri => 'https://adcenter.microsoft.com/v6',
         element_name => 'AgeGenderDemographicReportColumn',
         element_type => 'AgeGenderDemographicReportColumn'
     },
     ArrayOfBatchError => {
-        namespace_uri => 'https://adcenter.microsoft.com/v7',
+        namespace_uri => 'https://adcenter.microsoft.com/v6',
         element_name => 'BatchError',
         element_type => 'BatchError'
     },
     ArrayOfBehavioralPerformanceReportColumn => {
-        namespace_uri => 'https://adcenter.microsoft.com/v7',
+        namespace_uri => 'https://adcenter.microsoft.com/v6',
         element_name => 'BehavioralPerformanceReportColumn',
         element_type => 'BehavioralPerformanceReportColumn'
     },
     ArrayOfBehavioralTargetReportColumn => {
-        namespace_uri => 'https://adcenter.microsoft.com/v7',
+        namespace_uri => 'https://adcenter.microsoft.com/v6',
         element_name => 'BehavioralTargetReportColumn',
         element_type => 'BehavioralTargetReportColumn'
     },
     ArrayOfBudgetSummaryReportColumn => {
-        namespace_uri => 'https://adcenter.microsoft.com/v7',
+        namespace_uri => 'https://adcenter.microsoft.com/v6',
         element_name => 'BudgetSummaryReportColumn',
         element_type => 'BudgetSummaryReportColumn'
     },
     ArrayOfCampaignPerformanceReportColumn => {
-        namespace_uri => 'https://adcenter.microsoft.com/v7',
+        namespace_uri => 'https://adcenter.microsoft.com/v6',
         element_name => 'CampaignPerformanceReportColumn',
         element_type => 'CampaignPerformanceReportColumn'
     },
     ArrayOfCampaignReportScope => {
-        namespace_uri => 'https://adcenter.microsoft.com/v7',
+        namespace_uri => 'https://adcenter.microsoft.com/v6',
         element_name => 'CampaignReportScope',
         element_type => 'CampaignReportScope'
     },
     ArrayOfConversionPerformanceReportColumn => {
-        namespace_uri => 'https://adcenter.microsoft.com/v7',
+        namespace_uri => 'https://adcenter.microsoft.com/v6',
         element_name => 'ConversionPerformanceReportColumn',
         element_type => 'ConversionPerformanceReportColumn'
     },
+    ArrayOfDate => {
+        namespace_uri => 'https://adcenter.microsoft.com/v6',
+        element_name => 'Date',
+        element_type => 'Date'
+    },
     ArrayOfDestinationUrlPerformanceReportColumn => {
-        namespace_uri => 'https://adcenter.microsoft.com/v7',
+        namespace_uri => 'https://adcenter.microsoft.com/v6',
         element_name => 'DestinationUrlPerformanceReportColumn',
         element_type => 'DestinationUrlPerformanceReportColumn'
     },
     ArrayOfGoalsAndFunnelsReportColumn => {
-        namespace_uri => 'https://adcenter.microsoft.com/v7',
+        namespace_uri => 'https://adcenter.microsoft.com/v6',
         element_name => 'GoalsAndFunnelsReportColumn',
         element_type => 'GoalsAndFunnelsReportColumn'
     },
     ArrayOfKeywordPerformanceReportColumn => {
-        namespace_uri => 'https://adcenter.microsoft.com/v7',
+        namespace_uri => 'https://adcenter.microsoft.com/v6',
         element_name => 'KeywordPerformanceReportColumn',
         element_type => 'KeywordPerformanceReportColumn'
     },
     ArrayOfMetroAreaDemographicReportColumn => {
-        namespace_uri => 'https://adcenter.microsoft.com/v7',
+        namespace_uri => 'https://adcenter.microsoft.com/v6',
         element_name => 'MetroAreaDemographicReportColumn',
         element_type => 'MetroAreaDemographicReportColumn'
     },
     ArrayOfOperationError => {
-        namespace_uri => 'https://adcenter.microsoft.com/v7',
+        namespace_uri => 'https://adcenter.microsoft.com/v6',
         element_name => 'OperationError',
         element_type => 'OperationError'
     },
     ArrayOfPublisherUsagePerformanceReportColumn => {
-        namespace_uri => 'https://adcenter.microsoft.com/v7',
+        namespace_uri => 'https://adcenter.microsoft.com/v6',
         element_name => 'PublisherUsagePerformanceReportColumn',
         element_type => 'PublisherUsagePerformanceReportColumn'
     },
-    ArrayOfRichAdComponentPerformanceReportColumn => {
-        namespace_uri => 'https://adcenter.microsoft.com/v7',
-        element_name => 'RichAdComponentPerformanceReportColumn',
-        element_type => 'RichAdComponentPerformanceReportColumn'
-    },
     ArrayOfSearchQueryPerformanceReportColumn => {
-        namespace_uri => 'https://adcenter.microsoft.com/v7',
+        namespace_uri => 'https://adcenter.microsoft.com/v6',
         element_name => 'SearchQueryPerformanceReportColumn',
         element_type => 'SearchQueryPerformanceReportColumn'
     },
     ArrayOfSegmentationReportColumn => {
-        namespace_uri => 'https://adcenter.microsoft.com/v7',
+        namespace_uri => 'https://adcenter.microsoft.com/v6',
         element_name => 'SegmentationReportColumn',
         element_type => 'SegmentationReportColumn'
     },
     ArrayOfSitePerformanceReportColumn => {
-        namespace_uri => 'https://adcenter.microsoft.com/v7',
+        namespace_uri => 'https://adcenter.microsoft.com/v6',
         element_name => 'SitePerformanceReportColumn',
         element_type => 'SitePerformanceReportColumn'
     },
     ArrayOfTacticChannelReportColumn => {
-        namespace_uri => 'https://adcenter.microsoft.com/v7',
+        namespace_uri => 'https://adcenter.microsoft.com/v6',
         element_name => 'TacticChannelReportColumn',
         element_type => 'TacticChannelReportColumn'
     },
     ArrayOfTrafficSourcesReportColumn => {
-        namespace_uri => 'https://adcenter.microsoft.com/v7',
+        namespace_uri => 'https://adcenter.microsoft.com/v6',
         element_name => 'TrafficSourcesReportColumn',
         element_type => 'TrafficSourcesReportColumn'
     },
+    ArrayOfint => {
+        namespace_uri => 'http://schemas.microsoft.com/2003/10/Serialization/Arrays',
+        element_name => 'int',
+        element_type => 'int'
+    },
     ArrayOflong => {
         namespace_uri => 'http://schemas.microsoft.com/2003/10/Serialization/Arrays',
         element_name => 'long',
@@ -464,6 +464,7 @@ sub _array_types {
 }
 
 __PACKAGE__->mk_accessors(qw/
+    EndPoint
     ApplicationToken
     CustomerAccountId
     CustomerId
