@@ -1,5 +1,5 @@
 package Microsoft::AdCenter::ReportingService::AccountReportScope;
-# Copyright (C) 2011 Xerxes Tsang
+# Copyright (C) 2010 Xerxes Tsang
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of Perl Artistic License.
 
@@ -19,7 +19,7 @@ sub _type_name {
 }
 
 sub _namespace_uri {
-    return 'https://adcenter.microsoft.com/v7';
+    return 'https://adcenter.microsoft.com/v6';
 }
 
 our @_attributes = (qw/
@@ -32,7 +32,7 @@ sub _attributes {
 }
 
 our %_attribute_type = (
-    AccountIds => 'ArrayOflong',
+    AccountIds => 'ArrayOfint',
 );
 
 sub _attribute_type {
@@ -43,19 +43,7 @@ sub _attribute_type {
     return $self->SUPER::_attribute_type($attribute);
 }
 
-our %_attribute_min_occurs = (
-    AccountIds => 0,
-);
-
-sub _attribute_min_occurs {
-    my ($self, $attribute) = @_;
-    if (exists $_attribute_min_occurs{$attribute}) {
-        return $_attribute_min_occurs{$attribute};
-    }
-    return $self->SUPER::_attribute_min_occurs($attribute);
-}
-
-__PACKAGE__->mk_accessors(@_attributes);
+__PACKAGE__->mk_accessors(__PACKAGE__->_attributes);
 
 1;
 
@@ -73,7 +61,7 @@ Creates a new instance
 
 =head2 AccountIds
 
-Gets/sets AccountIds (ArrayOflong)
+Gets/sets AccountIds (ArrayOfint)
 
 =cut
 
