@@ -1,5 +1,5 @@
 package Microsoft::AdCenter::ReportingService::AdDynamicTextPerformanceReportRequest;
-# Copyright (C) 2011 Xerxes Tsang
+# Copyright (C) 2010 Xerxes Tsang
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of Perl Artistic License.
 
@@ -23,7 +23,7 @@ sub _type_name {
 }
 
 sub _namespace_uri {
-    return 'https://adcenter.microsoft.com/v7';
+    return 'https://adcenter.microsoft.com/v6';
 }
 
 our @_attributes = (qw/
@@ -55,23 +55,7 @@ sub _attribute_type {
     return $self->SUPER::_attribute_type($attribute);
 }
 
-our %_attribute_min_occurs = (
-    Aggregation => 1,
-    Columns => 1,
-    Filter => 0,
-    Scope => 1,
-    Time => 1,
-);
-
-sub _attribute_min_occurs {
-    my ($self, $attribute) = @_;
-    if (exists $_attribute_min_occurs{$attribute}) {
-        return $_attribute_min_occurs{$attribute};
-    }
-    return $self->SUPER::_attribute_min_occurs($attribute);
-}
-
-__PACKAGE__->mk_accessors(@_attributes);
+__PACKAGE__->mk_accessors(__PACKAGE__->_attributes);
 
 1;
 
