@@ -1,5 +1,5 @@
 package Microsoft::AdCenter::ReportingService::AdPerformanceReportFilter;
-# Copyright (C) 2011 Xerxes Tsang
+# Copyright (C) 2010 Xerxes Tsang
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of Perl Artistic License.
 
@@ -19,13 +19,12 @@ sub _type_name {
 }
 
 sub _namespace_uri {
-    return 'https://adcenter.microsoft.com/v7';
+    return 'https://adcenter.microsoft.com/v6';
 }
 
 our @_attributes = (qw/
     AdDistribution
     AdType
-    DeviceType
     LanguageAndRegion
 /);
 
@@ -37,7 +36,6 @@ sub _attributes {
 our %_attribute_type = (
     AdDistribution => 'AdDistributionReportFilter',
     AdType => 'AdTypeReportFilter',
-    DeviceType => 'DeviceTypeReportFilter',
     LanguageAndRegion => 'LanguageAndRegionReportFilter',
 );
 
@@ -49,22 +47,7 @@ sub _attribute_type {
     return $self->SUPER::_attribute_type($attribute);
 }
 
-our %_attribute_min_occurs = (
-    AdDistribution => 0,
-    AdType => 0,
-    DeviceType => 0,
-    LanguageAndRegion => 0,
-);
-
-sub _attribute_min_occurs {
-    my ($self, $attribute) = @_;
-    if (exists $_attribute_min_occurs{$attribute}) {
-        return $_attribute_min_occurs{$attribute};
-    }
-    return $self->SUPER::_attribute_min_occurs($attribute);
-}
-
-__PACKAGE__->mk_accessors(@_attributes);
+__PACKAGE__->mk_accessors(__PACKAGE__->_attributes);
 
 1;
 
@@ -88,10 +71,6 @@ Gets/sets AdDistribution (AdDistributionReportFilter)
 
 Gets/sets AdType (AdTypeReportFilter)
 
-=head2 DeviceType
-
-Gets/sets DeviceType (DeviceTypeReportFilter)
-
 =head2 LanguageAndRegion
 
 Gets/sets LanguageAndRegion (LanguageAndRegionReportFilter)
